@@ -35,8 +35,10 @@ class BaseManager(object):
         self.enter_room(sid, namespace, sid)
 
     def is_connected(self, sid, namespace):
-        return sid in self.rooms[namespace][None] and \
-            self.rooms[namespace][None][sid]
+        try:
+            return self.rooms[namespace][None][sid]
+        except KeyError:
+            pass
 
     def disconnect(self, sid, namespace):
         """Register a client disconnect from a namespace."""
@@ -81,9 +83,12 @@ class BaseManager(object):
     def get_rooms(self, sid, namespace):
         """Return the rooms a client is in."""
         r = []
-        for room_name, room in six.iteritems(self.rooms[namespace]):
-            if room_name is not None and sid in room and room[sid]:
-                r.append(room_name)
+        try:
+            for room_name, room in six.iteritems(self.rooms[namespace]):
+                if room_name is not None and sid in room and room[sid]:
+                    r.append(room_name)
+        except KeyError:
+            pass
         return r
 
     def emit(self, event, data, namespace, room=None, skip_sid=None,
